@@ -1,6 +1,7 @@
+from .adapters import from_pydantic
 from .encoders import CSVEncoder, JSONEncoder, XMLEncoder
 from .extraction import create_extraction_chain
-from .nodes import Number, Object, Text
+from .nodes import Number, Object, Option, Selection, Text
 from .type_descriptors import (
     BulletPointDescriptor,
     TypeDescriptor,
@@ -8,14 +9,17 @@ from .type_descriptors import (
 )
 
 __all__ = (
-    "Text",
-    "Object",
-    "Number",
+    "BulletPointDescriptor",
     "create_extraction_chain",
+    "CSVEncoder",
+    "from_pydantic",
+    "JSONEncoder",
+    "Number",
+    "Object",
+    "Option",
+    "Selection",
+    "Text",
     "TypeDescriptor",
     "TypeScriptDescriptor",
-    "BulletPointDescriptor",
-    "CSVEncoder",
     "XMLEncoder",
-    "JSONEncoder",
 )
