@@ -1,8 +1,20 @@
 """Definitions of input elements."""
 import abc
 import copy
+import inspect
+import operator
 import re
-from typing import Any, Generic, Mapping, Optional, Sequence, Tuple, TypeVar, Union
+from typing import (
+    Any,
+    Generic,
+    List,
+    Mapping,
+    Optional,
+    Sequence,
+    Tuple,
+    TypeVar,
+    Union,
+)
 
 # For now, limit what's allowed for identifiers.
 # The main constraints
@@ -16,6 +28,15 @@ VALID_IDENTIFIER_PATTERN = re.compile(r"^[a-z_][0-9a-z_]*$")
 T = TypeVar("T")
 
 
+def _get_all_slots(node: "AbstractSchemaNode") -> List[str]:
+    """Get a list of all slots."""
+    slots: List[str] = []
+    for class_ in inspect.getmro(type(node)):
+        if hasattr(class_, "__slots__"):
+            slots.extend(class_.__slots__)
+    return sorted(slots)
+
+
 class AbstractVisitor(Generic[T], abc.ABC):
     """An abstract visitor. Define here to avoid cyclical imports for now."""
 
@@ -89,6 +110,23 @@ class AbstractSchemaNode(abc.ABC):
             new_object.description = description
         return new_object
 
+    def __repr__(self) -> str:
+        """Get representation of the node."""
+        return f"{type(self).__name__}({self.id})"
+
+    def __eq__(self: Any, other: Any) -> bool:
+        """Equality check"""
+        if not isinstance(self, AbstractSchemaNode):
+            raise AssertionError(f"Cannot compare {type(self)} with {type(other)}")
+        if type(self) != type(other):
+            return False
+
+        if _get_all_slots(self) == _get_all_slots(other):
+            attr_getters = [operator.attrgetter(attr) for attr in self.__slots__]
+            return all(getter(self) == getter(other) for getter in attr_getters)
+
+        return False
+
 
 class ExtractionSchemaNode(AbstractSchemaNode, abc.ABC):
     """An abstract definition for inputs that involve extraction.
@@ -150,6 +188,10 @@ class Option(AbstractSchemaNode):
         examples: Sequence[str] = tuple(),
     ) -> None:
         """Initialize for extraction input."""
+        if many:
+            # TODO: Fix the type hierarchy so that `many` isn't provided to option.
+            raise ValueError("Option inputs cannot be many.")
+
         super().__init__(id=id, description=description, many=many)
         self.examples = examples
 
@@ -173,7 +215,7 @@ class Selection(AbstractSchemaNode):
         from the text: "I eat an apple every day.".
     """
 
-    __slots__ = "options", "null_examples"
+    __slots__ = "options", "examples", "null_examples"
 
     def __init__(
         self,
@@ -182,11 +224,16 @@ class Selection(AbstractSchemaNode):
         description: str = "",
         many: bool = False,
         options: Sequence[Option],
+        examples: Sequence[Tuple[str, Union[str, Sequence[str]]]] = tuple(),
         null_examples: Sequence[str] = tuple(),
     ) -> None:
         """Initialize for extraction input."""
         super().__init__(id=id, description=description, many=many)
+
+        if not options:
+            raise ValueError("Selection inputs must have at least one option.")
         self.options = options
+        self.examples = examples
         self.null_examples = null_examples
 
     def accept(self, visitor: AbstractVisitor[T]) -> T:
@@ -223,7 +270,7 @@ class Object(AbstractSchemaNode):
         from the text: "I eat an apple every day.".
     """
 
-    __slots__ = ("attributes", "examples", "group_as_object")
+    __slots__ = ("attributes", "examples")
 
     def __init__(
         self,
@@ -237,16 +284,11 @@ class Object(AbstractSchemaNode):
         examples: Sequence[
             Tuple[str, Mapping[str, Union[str, Sequence[str]]]]
         ] = tuple(),
-        # If false, will treat the inputs independent.
-        # Is there a better name for this?! I want it to be True by default
-        # which rules out as_input_bag
-        group_as_object: bool = True,
     ) -> None:
         """Initialize for extraction input."""
         super().__init__(id=id, description=description, many=many)
         self.attributes = attributes
         self.examples = examples
-        self.group_as_object = group_as_object
 
     def accept(self, visitor: AbstractVisitor[T]) -> T:
         """Accept a visitor."""
